#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void _aB_I__0__K__1___TwoPRep_G__0__F__1___Ab__up_0(const Libint_t* inteval);
#ifdef __cplusplus
};
#endif
